#
# spec file for package kcm_flatpak
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __requires_exclude qmlimport\\(org\\.kde\\.plasma\\.kcm\\.flatpakpermissions

%bcond_without released
Name:           kcm_flatpak
Version:        5.27.4
Release:        bp155.1.5
Summary:        Flatpak Permissions Management KCM
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            https://invent.kde.org/plasma/flatpak-kcm
Source:         https://download.kde.org/stable/plasma/%{version}/flatpak-kcm-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/flatpak-kcm-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
# PATCH-FIX-UPSTREAM
BuildRequires:  extra-cmake-modules >= 5.98.0
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Declarative)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5KCMUtils)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5Quick)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  pkgconfig(flatpak) >= 0.11.8
# Used by the .desktop file
Requires:       systemsettings5
Supplements:    (flatpak and plasma5-workspace)

%description
The KCM allows changing what permissions have been granted to installed Flatpak applications.

%lang_package

%prep
%autosetup -p1 -n flatpak-kcm-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%find_lang %{name} %{name}.lang

%files lang -f %{name}.lang

%files
%license LICENSES/*
%dir %{_kf5_sharedir}/kpackage/
%dir %{_kf5_sharedir}/kpackage/kcms/
%{_kf5_sharedir}/kpackage/kcms/kcm_flatpak/
%dir %{_kf5_plugindir}/plasma/
%dir %{_kf5_plugindir}/plasma/kcms/
%dir %{_kf5_plugindir}/plasma/kcms/systemsettings/
%{_kf5_plugindir}/plasma/kcms/systemsettings/kcm_flatpak.so
%{_kf5_applicationsdir}/kcm_flatpak.desktop

%changelog
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- Too many changes to list here
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Too many changes to list here
- Drop patches, now upstream:
  * 0001-Expose-FlatpakReferencesModel-to-QML.patch
  * 0002-Avoid-duplicating-connections-between-ref-and-its-re.patch
  * 0003-Port-from-NULL-to-nullptr.patch
  * 0004-Fix-GLib-memory-management-issue.patch
* Wed Mar  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Apply important fixes from the 5.27 branch:
  * 0001-Expose-FlatpakReferencesModel-to-QML.patch
  * 0002-Avoid-duplicating-connections-between-ref-and-its-re.patch
  * 0003-Port-from-NULL-to-nullptr.patch
  * 0004-Fix-GLib-memory-management-issue.patch
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- Changes since 5.27.1:
  * Adjust popup modals for the footer padding in KCM
  * UI: Adapt "Apply / Discard" dialog to narrow screens: turn row layout into column
  * Plasma/5.27: Revert partially last commit due to string freeze
  * UI: Add changed app's name & icon to the "Apply / Discard" dialog
  * UI: Reparent app switching dialog, so that it is centered to the whole view
  * Use standard QQC2 namespace for Dialog constants
  * UI: Dynamically create "Apply / Discard" dialog when switching apps
  * Move app changing logic out of delegate, fetch ref directly from model
  * UI: Don't try to reload app when clicking on the current one
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * DRY the code a bit
  * use range based for loops where possible
  * make clazy happy
  * typo--
  * always use frontend strings but convert to backend strings when saving (kde#465818)
  * add a test case to cover BUG 465818
  * don't needlessly define a default constructor
  * don't else after return
  * initialize variables where possible
  * don't declare multiple variables in a single line
  * don't const primitives
  * pass qstrings by reference where appropriate
  * refresh git-blame-ignore-revs for latest clang-format run
  * automatic clang-format run (clang 15)
  * enable clang-format
  * print a cmake feature summary
  * don't needlessly define default dtors
  * mark constructors explicit where appropriate
  * don't declare getters as slots
  * sort includes
  * Avoid creating empty fs permission entry from overrides
* Mon Feb 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Tarball got respun. Changes:
  * Avoid creating empty fs permission entry from overrides
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- Changes since 5.26.90:
  * Keep Advanced Permissions section collapsed by default
  * Copy gitignore from systemsettings
  * Fix memory management for graph of cross-referenced objects
  * Fix signatures of overridden methods in model to match super-class
  * Generate desktop file for KCM
  * Use QStandardPaths::GenericDataLocation instead of hardcoding .local/share (kde#465339)
  * Fix rows height, including partially hidden text field at the bottom
  * Add "=" label between environment variable name and value in dialog
  * Add workaround for broken ListView layout (rows drifting down on scroll)
  * Clean up QML/JavaScript, simplify some code
  * Specify translation domain (kde#464573)
  * flatpakpermission: Make sure editPerm() cannot access out of bounds
  * Add installed user apps to list of installed apps
  * Find icons by using the deploy dir of the installed flatpak
  * Initialise default index
  * Make views frameless
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Initial package
